import sys

from rich.console import Console
from rich.syntax import PygmentsSyntaxTheme, Syntax

from showfile.theme import MonokaiProStyle

from .theme import MonokaiProStyle


def run():
    console = Console()
    syntax = Syntax.from_path(sys.argv[1])
    syntax._theme = PygmentsSyntaxTheme(MonokaiProStyle)
    console.print(syntax)



from pygments.style import Style
from pygments.token import (
    Comment,
    Error,
    Generic,
    Keyword,
    Literal,
    Name,
    Number,
    Operator,
    Other,
    Punctuation,
    String,
    Text,
    Whitespace
)

DARK_GREY = "#2D2A2E"
LIGHT_GREY= "#69676c"
RED = "#FF6188"
GREEN = "#A9DC76"
YELLOW = "#FFD866"
ORANGE = "#FC9867"
PURPLE = "#AB9DF2"
CYAN = "#78DCE8"
WHITE = "#f7f1ff"

class MonokaiProStyle(Style):
    """
    This style mimics the Monokai Pro color scheme.
    """

    background_color = DARK_GREY
    highlight_color = "#49483e"

    styles = {
        # No corresponding class for the following:
        Text:                      WHITE, # class:  ''
        Error:                     "#FF6188 bg:#1e0010", # class: 'err'

        Comment:                   "italic #69676c", # class: 'c'
        Comment.Multiline:         YELLOW,        # class: 'cm'

        Keyword:                   RED, # class: 'k'
        Keyword.Namespace:         RED, # class: 'kn'
        Keyword.Reserved:          CYAN,   # class: 'kr'
        Keyword.Constant:          PURPLE,   # class: 'kc'

        Operator:                  RED, # class: 'o'

        Punctuation:               WHITE, # class: 'p'

        Name:                      WHITE, # class: 'n'
        Name.Attribute:            GREEN, # class: 'na' - to be revised
        Name.Builtin:              GREEN,        # class: 'nb'
        Name.Builtin.Pseudo:       ORANGE,        # class: 'bp'
        Name.Exception:            CYAN,   # class: 'ne'
        Name.Class:                CYAN, # class: 'nc' - to be revised
        Name.Decorator:            PURPLE, # class: 'nd' - to be revised
        Name.Exception:            "italic #78DCE8", # class: 'ne'
        Name.Function:             GREEN, # class: 'nf'
        Name.Tag:                  RED, # class: ''
        Name.Property:             ORANGE,        # class: 'py'

        Number:                    PURPLE, # class: 'm'

        Literal:                   PURPLE, # class: 'l'
        Literal.Date:              ORANGE, # class: 'ld'

        String:                    YELLOW, # class: 's'
        String.Regex:              ORANGE,        # class: 'sr'

        Generic.Deleted:           YELLOW, # class: 'gd',
        Generic.Emph:              "italic",  # class: 'ge'
        Generic.Inserted:          GREEN, # class: 'gi'
        Generic.Strong:            "bold",    # class: 'gs'
        Generic.Subheading:        LIGHT_GREY, # class: 'gu'
    }



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="showfile",
    version="0.1.2",
    author="Wasi Master",
    author_email="arianmollik323@gmail.com",
    long_description=long_description,
    long_description_content_type="text/markdown",
    description="A tool to view files with their proper syntax highlighting in the console",
    url="https://wasi-master.github.io/showfile/",
    project_urls={
        "Github": "https://github.com/wasi-master/showfile",
        "Bug Tracker": "https://github.com/wasi-master/showfile/issues",
        "Documentation": "https://github.com/wasi-master/showfile/blob/main/README.md",
        "Say Thanks": "https://saythanks.io/to/arianmollik323@gmail.com",
    },
    packages=["showfile"],
    license="MIT",
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Development Status :: 4 - Beta",
        "Environment :: Console",
        "Intended Audience :: Developers",
        "Intended Audience :: End Users/Desktop",
        "Natural Language :: English",
        "Topic :: Terminals",
        "Topic :: Text Processing",
        "Topic :: Text Processing :: General"
    ],
    python_requires=">=3.6",
    install_requires=["rich"],
    entry_points={
        "console_scripts": ["showfile=showfile.main:run"],
    },
)
